# Installing Test Pilot

We recommend using [pipx](https://pypa.github.io/pipx/) to install
Test Pilot.
First [install pipx](https://pypa.github.io/pipx/#install-pipx) then run:

```terminal
pipx install testpilot
```

You now have Test Pilot installed! For some help run:

```
testpilot --help
```

Upgrading
---------

To upgrade to the latest version run:

```terminal
pipx upgrade testpilot
```

To see what version you have run:

```terminal
testpilot --version
```

Uninstalling
------------

To uninstall run:

```
pipx uninstall testpilot
```
